package com.huimv.guowei.admin.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.guowei.admin.common.utils.Result;
import com.huimv.guowei.admin.common.utils.ResultCode;
import com.huimv.guowei.admin.entity.*;
import com.huimv.guowei.admin.mapper.*;
import com.huimv.guowei.admin.service.IBaseDuckInfoService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author author
 * @since 2023-06-01
 */
@Service
public class BaseDuckInfoServiceImpl extends ServiceImpl<BaseDuckInfoMapper, BaseDuckInfo> implements IBaseDuckInfoService {

    @Autowired
    private BaseDuckInfoMapper duckInfoMapper;
    @Autowired
    private EnvMoveCallMapper moveCallMapper;
    @Autowired
    private EnvRegularCallFeedingMapper feedingMapper;
    @Autowired
    private EnvRegularCallEggMapper eggMapper;
    @Autowired
    private DuckHealthInfoMapper healthInfoMapper;
    @Autowired
    private DuckImmunityInfoMapper infoMapper;
    @Override
    public Result listDuck(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String code = paramsMap.get("code");//前端传来的是编号
        String location = paramsMap.get("location");//前端传来的是位置名字
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        if (pageNum == null || "".equals(pageNum)) {
            pageNum = "1";
        }
        if (pageSize == null || "".equals(pageSize)) {
            pageSize = "10";
        }
        QueryWrapper<BaseDuckInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(StringUtils.isNotBlank(code), "id", code).eq(StringUtils.isNotBlank(location), "unit_name", location);
        Page<BaseDuckInfo> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, duckInfoMapper.selectPage(page, queryWrapper));
    }

    @Override
    public Result addDuck(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) throws ParseException {
        BaseDuckInfo baseDuckInfo = new BaseDuckInfo();
        baseDuckInfo.setId(Integer.parseInt(paramsMap.get("id")));
        baseDuckInfo.setDuckBreed(Integer.parseInt(paramsMap.get("duckBreed")));
        baseDuckInfo.setDuckSex(Integer.parseInt(paramsMap.get("duckSex")));
        baseDuckInfo.setDuckBirthplace(paramsMap.get("duckBirthPlace"));
        String date = paramsMap.get("duckBirthDay");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd ");
        baseDuckInfo.setDuckBirthday(sdf.parse(date));
        baseDuckInfo.setGenotype(paramsMap.get("genotype"));
        BigDecimal big = new BigDecimal(paramsMap.get("nowWeight"));
        baseDuckInfo.setNowWeight(big);
        baseDuckInfo.setUnitId(Integer.parseInt(paramsMap.get("unitId")));
        baseDuckInfo.setBreedingEnv(paramsMap.get("breedEnv"));
        if (Integer.parseInt(paramsMap.get("duckSex")) == 1) {
            BigDecimal rate = new BigDecimal(paramsMap.get("hatchRate"));
            baseDuckInfo.setHatchRate(rate);
        }
        baseDuckInfo.setFatherNum(paramsMap.get("fatherNum"));
        baseDuckInfo.setMotherNum(paramsMap.get("motherNum"));
        baseDuckInfo.setFatherGenotype(paramsMap.get("fatherGenotype"));
        baseDuckInfo.setMotherGenotype(paramsMap.get("motherGenotype"));
        baseDuckInfo.setSpecialNeeds(paramsMap.get("specialNeeds"));
        baseDuckInfo.setIsCage(0);
        QueryWrapper<BaseDuckInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("id", paramsMap.get("id")).or().eq("unit_id", paramsMap.get("unitId"));
        Integer integer = duckInfoMapper.selectCount(queryWrapper);
        baseDuckInfo.setDuckImgUrl(paramsMap.get("imgUrl"));
        if (integer == 0) {
            duckInfoMapper.insert(baseDuckInfo);
            return new Result(ResultCode.SUCCESS);
        } else {
            return new Result(10001, "编码已存在或该笼位已使用", false);
        }
    }

    @Override
    public Result editDuck(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String id = paramsMap.get("id");
        String isCage = paramsMap.get("isCage");
        BaseDuckInfo baseDuckInfo = duckInfoMapper.selectById(id);
        baseDuckInfo.setIsCage(Integer.parseInt(isCage));
        duckInfoMapper.updateById(baseDuckInfo);
        return new Result(ResultCode.SUCCESS);
    }

    @Override
    public Result listDuckById(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String id = paramsMap.get("id");
        QueryWrapper<BaseDuckInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("id", id);
        BaseDuckInfo baseDuckInfo = duckInfoMapper.selectOne(queryWrapper);
        return new Result(ResultCode.SUCCESS, baseDuckInfo);
    }

}
