package com.huimv.guowei.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.guowei.admin.common.utils.Result;
import com.huimv.guowei.admin.common.utils.ResultCode;
import com.huimv.guowei.admin.entity.DuckHealthInfo;
import com.huimv.guowei.admin.mapper.DuckHealthInfoMapper;
import com.huimv.guowei.admin.service.IDuckHealthInfoService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author author
 * @since 2023-06-01
 */
@Service
public class DuckHealthInfoServiceImpl extends ServiceImpl<DuckHealthInfoMapper, DuckHealthInfo> implements IDuckHealthInfoService {

    @Autowired
    private DuckHealthInfoMapper healthInfoMapper;

    @Override
    public Result listById(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String duckNum = paramsMap.get("duckCode");
        String startDate = paramsMap.get("startDate");
        String endDate = paramsMap.get("endDate");
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");

        if (pageNum == null || "".equals(pageNum)) {
            pageNum = "1";
        }
        if (pageSize == null || "".equals(pageSize)) {
            pageSize = "10";
        }
        Date date = new Date();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        String format = sdf.format(date);
        if (StringUtils.isBlank(startDate)) {
            startDate = format + " 00:00:00";
        }else {
            startDate = startDate + " 00:00:00";
        }
        if (StringUtils.isBlank(endDate)) {
            endDate = format + " 23:59:59";
        }else {
            endDate = endDate + " 23:59:59";
        }

        QueryWrapper<DuckHealthInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("duck_num", duckNum).between( "health_date", startDate, endDate).orderByAsc("health_date");
        Page<DuckHealthInfo> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, healthInfoMapper.selectPage(page, queryWrapper));
    }

    @Override
    public Result addHealth(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) throws ParseException {
        String duckNum = paramsMap.get("duckCode");
        String date = paramsMap.get("date");
        String healthResult = paramsMap.get("healthResult");
        String treatmentMeasure = paramsMap.get("treatmentMeasure");
        DuckHealthInfo healthInfo = new DuckHealthInfo();
        healthInfo.setDuckNum(duckNum);
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        healthInfo.setHealthDate(sdf.parse(date));
        healthInfo.setHealthResult(healthResult);
        healthInfo.setTreatmentMeasure(treatmentMeasure);
        healthInfoMapper.insert(healthInfo);
        return new Result(ResultCode.SUCCESS);
    }


}
