package com.huimv.guowei.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.guowei.admin.common.utils.Result;
import com.huimv.guowei.admin.common.utils.ResultCode;
import com.huimv.guowei.admin.entity.DuckImmunityInfo;
import com.huimv.guowei.admin.mapper.DuckImmunityInfoMapper;
import com.huimv.guowei.admin.service.IDuckImmunityInfoService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author author
 * @since 2023-06-01
 */
@Service
public class DuckImmunityInfoServiceImpl extends ServiceImpl<DuckImmunityInfoMapper, DuckImmunityInfo> implements IDuckImmunityInfoService {

    @Autowired
    private DuckImmunityInfoMapper infoMapper;
    @Override
    public Result listById(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String duckNum = paramsMap.get("duckCode");
        String startDate = paramsMap.get("startDate");
        String endDate = paramsMap.get("endDate");
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");

        Date date = new Date();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        String format = sdf.format(date);
        if (StringUtils.isBlank(startDate)) {
            startDate = format + " 00:00:00";
        } else {
            startDate = startDate + " 00:00:00";
        }
        if (StringUtils.isBlank(endDate)) {
            endDate = format + " 23:59:59";
        } else {
            endDate = endDate + " 23:59:59";
        }
        if (pageNum == null || "".equals(pageNum)) {
            pageNum = "1";
        }
        if (pageSize == null || "".equals(pageSize)) {
            pageSize = "10";
        }
        QueryWrapper<DuckImmunityInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("duck_num", duckNum).between("health_date", startDate, endDate).orderByAsc("health_date");
        Page<DuckImmunityInfo> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, infoMapper.selectPage(page, queryWrapper));
    }

    @Override
    public Result addImmunity(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) throws ParseException {
        String duckNum = paramsMap.get("duckCode");
        String date = paramsMap.get("date");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        Date date1 = sdf.parse(date);
        String vaccination = paramsMap.get("vaccination");//接种疫苗
        DuckImmunityInfo immunityInfo = new DuckImmunityInfo();
        immunityInfo.setDuckNum(duckNum);
        immunityInfo.setHealthDate(date1);
        immunityInfo.setVaccination(vaccination);
        infoMapper.insert(immunityInfo);
        return new Result(ResultCode.SUCCESS);
    }

}
