package com.huimv.guowei.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.guowei.admin.common.utils.DataUill;
import com.huimv.guowei.admin.common.utils.Result;
import com.huimv.guowei.admin.common.utils.ResultCode;
import com.huimv.guowei.admin.entity.EnvMoveCall;
import com.huimv.guowei.admin.entity.EnvRegularCallEgg;
import com.huimv.guowei.admin.mapper.EnvMoveCallMapper;
import com.huimv.guowei.admin.service.IEnvMoveCallService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.Calendar;
import java.util.Date;
import java.util.Map;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author author
 * @since 2023-06-01
 */
@Service
public class EnvMoveCallServiceImpl extends ServiceImpl<EnvMoveCallMapper, EnvMoveCall> implements IEnvMoveCallService {

    @Autowired
    private EnvMoveCallMapper moveCallMapper;

    @Override
    public Result listById(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String type = paramsMap.get("type");//显示类型
        String duckCode = paramsMap.get("duckCode");
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        if (pageNum == null || "".equals(pageNum)) {
            pageNum = "1";
        }
        if (pageSize == null || "".equals(pageSize)) {
            pageSize = "10";
        }
        if ("1".equals(type)) {
            QueryWrapper<EnvMoveCall> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("duck_code", duckCode).orderByAsc("dayage");
            Page<EnvMoveCall> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
            return new Result(ResultCode.SUCCESS, moveCallMapper.selectPage(page, queryWrapper));
        } else {
            String dateType = paramsMap.get("dateType");
            QueryWrapper<EnvMoveCall> queryWrapper = new QueryWrapper<>();
            if ("1".equals(dateType)) {
                Date timesmorning = DataUill.getTimesmorning();
                queryWrapper.eq("duck_code", duckCode).ge("call_date", timesmorning).orderByAsc("call_date");

            } else if ("2".equals(dateType)) {
                Calendar calendar = Calendar.getInstance();
                calendar.set(Calendar.DATE, calendar.get(Calendar.DATE) - 7);
                queryWrapper.eq("duck_code", duckCode).ge("call_date", calendar.getTime()).orderByAsc("call_date");

            } else if ("3".equals(dateType)) {
                Date timesMonthmorning = DataUill.getTimesMonthmorning();
                queryWrapper.eq("duck_code", duckCode).ge("call_date", timesMonthmorning).orderByAsc("call_date");

            } else {
                String startDate = paramsMap.get("startDate");
                String endDate = paramsMap.get("endDate");
                startDate = startDate + " 00:00:00";
                endDate = endDate + " 23:59:59";
                queryWrapper.eq("duck_code", duckCode).between("call_date", startDate, endDate).orderByAsc("call_date");
            }
            return new Result(ResultCode.SUCCESS, moveCallMapper.selectList(queryWrapper));
        }
    }
}
