package com.huimv.guowei.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.guowei.admin.common.utils.DataUill;
import com.huimv.guowei.admin.common.utils.Result;
import com.huimv.guowei.admin.common.utils.ResultCode;
import com.huimv.guowei.admin.entity.EnvRegularCallEgg;
import com.huimv.guowei.admin.entity.EnvRegularCallFeeding;
import com.huimv.guowei.admin.mapper.EnvRegularCallEggMapper;
import com.huimv.guowei.admin.service.IEnvRegularCallEggService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Map;

/**
 * <p>
 * 固定电子秤 服务实现类
 * </p>
 *
 * @author author
 * @since 2023-06-01
 */
@Service
public class EnvRegularCallEggServiceImpl extends ServiceImpl<EnvRegularCallEggMapper, EnvRegularCallEgg> implements IEnvRegularCallEggService {

    @Autowired
    private EnvRegularCallEggMapper eggMapper;

    @Override
    public Result listById(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String type = paramsMap.get("type");//显示类型
        String duckCode = paramsMap.get("duckCode");
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        if (pageNum == null || "".equals(pageNum)) {
            pageNum = "1";
        }
        if (pageSize == null || "".equals(pageSize)) {
            pageSize = "10";
        }
        if ("1".equals(type)) {
            QueryWrapper<EnvRegularCallEgg> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("duck_code", duckCode).orderByAsc("dayage");
            Page<EnvRegularCallEgg> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
            return new Result(ResultCode.SUCCESS, eggMapper.selectPage(page, queryWrapper));
        } else {
            String dateType = paramsMap.get("dateType");
            QueryWrapper<EnvRegularCallEgg> queryWrapper = new QueryWrapper<>();
            if ("1".equals(dateType)) {
                Date timesmorning = DataUill.getTimesmorning();
                queryWrapper.eq("duck_code", duckCode).ge("call_date", timesmorning).orderByAsc("call_date");

            } else if ("2".equals(dateType)) {
                Calendar calendar = Calendar.getInstance();
                calendar.set(Calendar.DATE, calendar.get(Calendar.DATE) - 7);
                queryWrapper.eq("duck_code", duckCode).ge("call_date", calendar.getTime()).orderByAsc("call_date");

            } else if ("3".equals(dateType)) {
                Date timesMonthmorning = DataUill.getTimesMonthmorning();
                queryWrapper.eq("duck_code", duckCode).ge("call_date", timesMonthmorning).orderByAsc("call_date");

            } else {
                String startDate = paramsMap.get("startDate");
                String endDate = paramsMap.get("endDate");
                startDate = startDate + " 00:00:00";
                endDate = endDate + " 23:59:59";
                queryWrapper.eq("duck_code", duckCode).between("call_date", startDate, endDate).orderByAsc("call_date");
            }
            return new Result(ResultCode.SUCCESS, eggMapper.selectList(queryWrapper));
        }
    }

    @Override
    public Result addEgg(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) throws ParseException {
        String duckCode = paramsMap.get("duckCode");
        String date = paramsMap.get("date");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        String eggNum = paramsMap.get("eggNum");
        String eggWeight = paramsMap.get("eggWeight");
        EnvRegularCallEgg egg = new EnvRegularCallEgg();
        egg.setDuckCode(duckCode);
        egg.setDuckWeight(Integer.parseInt(eggWeight));
        egg.setEggNum(Integer.parseInt(eggNum));
        egg.setCallDate(sdf.parse(date));
        eggMapper.insert(egg);
        return new Result(10000,"添加成功!",true);
    }

    @Override
    public Result updateEgg(HttpServletRequest httpServletRequest, EnvRegularCallEgg egg) {
        eggMapper.updateById(egg);
        return new Result(10000, "修改成功！", true);
    }

    @Override
    public Result deleteEgg(HttpServletRequest httpServletRequest, Map<String,String> paramsMap) {
        String id = paramsMap.get("id");//此时这里就是表中的id
        eggMapper.deleteById(id);
        return new Result(10000, "删除成功!", true);
    }

}
